package com.ininwork.onechuan_plugin;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.view.View;
import android.webkit.ConsoleMessage;
import android.webkit.WebChromeClient;
import android.webkit.WebResourceRequest;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.TextView;

import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

public class WebViewActivity extends AppCompatActivity {

    WebView wv_main;
    TextView tv_title;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.layout_webview);
        wv_main = findViewById(R.id.wv_main);
        tv_title = findViewById(R.id.tv_title);
        Intent intent = getIntent();
        String jsonParameters = intent.getStringExtra("jsonParameters");

        try {
            JSONObject jsonObject = new JSONObject(jsonParameters);
            String url = jsonObject.getString("url");
            String title = jsonObject.getString("title");

            tv_title.setText(title);
            wv_main.getSettings().setJavaScriptEnabled(true);
            wv_main.getSettings().setDomStorageEnabled(true);
            wv_main.setWebChromeClient(new WebChromeClient() {
                @Override
                public boolean onConsoleMessage(ConsoleMessage consoleMessage) {
                    LogUtil.LogVMessage("进入consoleMessage");
                    return super.onConsoleMessage(consoleMessage);
                }

                @Override
                public void onProgressChanged(WebView view, int newProgress) {
                    super.onProgressChanged(view, newProgress);
                    LogUtil.LogVMessage("加载进度==》" + newProgress);
                }
            });
            wv_main.setWebViewClient(new WebViewClient() {
                String referer = "http://oapi.onechuan.com";

                @Override
                public boolean shouldOverrideUrlLoading(WebView view, String url) {
//                    super.shouldOverrideUrlLoading()
                    boolean isAlipayInstall  = isAliPayInstalled(WebViewActivity.this);
                    boolean isWebPage = url.startsWith("http:")||url.startsWith("https:");
                    LogUtil.LogVMessage("url==>" + url);
                    //处理支付宝逻辑
                    if(url.contains("alipay")){
                        LogUtil.LogVMessage("url==>" + "进入alipay");
                        //尚未安装支付宝逻辑并且来的是网页链接

                        if (!isAlipayInstall&&isWebPage) {
//                            ToastUtil.doShowToast(WebViewActivity.this, "尚未安装支付宝,使用网页版支付");
                            view.loadUrl(url);
                        }
                        //安装支付宝并且来的是打开app的连接
                        else if(isAlipayInstall&&!isWebPage) {
                            Intent intent = new Intent(Intent.ACTION_VIEW,
                                    Uri.parse(url));
                            startActivity(intent);
                        }
                        else{
                            view.loadUrl(url);
                        }
                        return true;
                    }
                    else if(isWebPage){
                        LogUtil.LogVMessage("进入else");
                        Map<String, String> extraHeaders = new HashMap<String, String>();
                        extraHeaders.put("Referer", referer);
                        view.loadUrl(url, extraHeaders);
                        referer = url;
                        return true;//不调用系统的浏览器打开网页
                    }
                    else{
                        Intent intent = new Intent(Intent.ACTION_VIEW,
                                Uri.parse(url));
                        startActivity(intent);
                        return true;
                    }
                }
            });
            wv_main.loadUrl(url);
        } catch (JSONException e) {
            e.printStackTrace();
        }


    }


    /**
     * 检测是否安装支付宝
     *
     * @param context
     * @return
     */
    public static boolean isAliPayInstalled(Context context) {
        Uri uri = Uri.parse("alipays://platformapi/startApp");
        Intent intent = new Intent(Intent.ACTION_VIEW, uri);
        ComponentName componentName = intent.resolveActivity(context.getPackageManager());
        return componentName != null;
    }

    public void doFinish(View view) {
        if (wv_main!=null&&wv_main.canGoBack()){
            wv_main.goBack();
        }
        else{
            finish();
        }

    }
}
